@@ -10,7 +10,7 @@
 #'
 #' @examples
 #' \donttest{
-#'  dp_values()
+#' dp_values()
 #' }
 #'
 #' @return a tibble of trade values from DynastyProcess
@@ -22,7 +22,8 @@ dp_values <- function(file = c("values.csv", "values-players.csv", "values-picks
 
   utils::read.csv(
     glue::glue("https://github.com/DynastyProcess/data/raw/master/files/{file_name}"),
-    stringsAsFactors = FALSE) %>%
+    stringsAsFactors = FALSE
+  ) %>%
     dplyr::mutate(scrape_date = lubridate::as_date(.data$scrape_date)) %>%
     dplyr::mutate_at(dplyr::vars(dplyr::ends_with("id")), as.character) %>%
     tibble::tibble()
@@ -42,14 +43,11 @@ dp_values <- function(file = c("values.csv", "values-players.csv", "values-picks
 #' @return a tibble of player IDs
 #'
 #' @export
-
-
 dp_playerids <- function() {
-  read.csv(
+  utils::read.csv(
     glue::glue("https://github.com/DynastyProcess/data/raw/master/files/db_playerids.csv"),
     stringsAsFactors = FALSE
   ) %>%
     dplyr::mutate_at(dplyr::vars(dplyr::ends_with("id")), as.character) %>%
     tibble::tibble()
 }
-
