@@ -5,6 +5,9 @@ knitr::opts_chunk$set(
 )
 options(dplyr.summarise.inform = FALSE)
 
+httptest::.mockPaths("../tests/testthat")
+httptest::use_mock_api()
+
 ## ----setup, message=FALSE-----------------------------------------------------
   library(ffscrapr)
   library(dplyr)
@@ -88,3 +91,6 @@ age_summary <- aaa_values %>%
 
 age_summary
 
+## ----include = FALSE----------------------------------------------------------
+httptest::stop_mocking()
+
