@@ -4,6 +4,9 @@ knitr::opts_chunk$set(
   comment = "#>"
 )
 options(dplyr.summarise.inform = FALSE)
+httptest::.mockPaths("../tests/testthat")
+httptest::use_mock_api()
+
 
 ## ----setup, message = FALSE---------------------------------------------------
 library(ffscrapr)
@@ -41,3 +44,6 @@ trending <- df_trending %>%
 
 trending
 
+## ----include = FALSE----------------------------------------------------------
+httptest::stop_mocking()
+
